@@ -4,6 +4,8 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "contacttemplatewidget.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "contactdefaulttemplate.h"
 
 #include <KLocalizedString>
@@ -30,7 +32,7 @@ ContactTemplateWidget::ContactTemplateWidget(const QString &title, QWidget *pare
     auto lay = new QVBoxLayout(this);
     auto lab = new QLabel(title);
     lay->addWidget(lab);
-    mListTemplate = new ContactTemplateListWidget(QStringLiteral("contactthemeeditorrc"));
+    mListTemplate = new ContactTemplateListWidget(u"contactthemeeditorrc"_s);
     mListTemplate->setWhatsThis(i18n("You can drag and drop element on editor to import template"));
     connect(mListTemplate, &ContactTemplateListWidget::insertTemplate, this, &ContactTemplateWidget::insertTemplate);
     lay->addWidget(mListTemplate);
